%% demo4

%%

clear
close all
filename = '2013_0115_163116AA.JPG';
img = im2double(rgb2gray(imread(filename)));
% crop rect from basics.m
rect = [637.5  484.5  732  470];
g = imcrop(img,rect);
imshow(g);



%% histogram, graythresh and im2bw
% level = graythresh(I) computes a global threshold (level) that 
% can be used to convert an intensity image to a binary image with im2bw. 
% level is a normalized intensity value that lies in the range [0, 1].
%
%The graythresh function uses Otsu's method, which chooses the threshold
% to minimize the intraclass variance of the black and white pixels.

imhist(g);
level = graythresh(g);
hold on
plot([level level],[0 1000],'k-','Linewidth',2);
hold off
fprintf('threshold %g\n',level);

%% convert to bw image

BW = im2bw(g,level);
imshow(BW);

%% bwconncomp
% CC = bwconncomp(BW) returns the connected components CC found in BW. 
% The binary image BW can have any dimension. 
% CC is a structure with four fields.

CC = bwconncomp(~BW);
disp(CC)

%% regionprops

stats = regionprops(CC)
n = CC.NumObjects;
fprintf('      object        area\n');
area = [stats.Area];
disp( [ [1:n]' area']);

%% centroids

centers = cat(1,stats.Centroid)

%% labelmatrix
% L = labelmatrix(CC) creates a label matrix from the connected components 
% structure CC returned by bwconncomp. The size of L is CC.ImageSize. 
% The elements of L are integer values greater than or equal to 0. 

L = labelmatrix(CC);

%% label2rgb
% RGB = label2rgb(L) converts a label matrix into an RGB color image 
% for the purpose of visualizing the labeled regions. 

RGB = label2rgb(L);
imshow(RGB);

%% select certain objects

idx = find(abs([stats.Area]-1400)<35);
BW2 = ismember(L,idx);
imshow(BW2);

%%  select first four objects

imshow(ismember(L,1:4));

%% select based on eccentricity

s = regionprops(CC,'Eccentricity');
idx = find([s.Eccentricity]<0.3);
imshow(ismember(L,idx));